@@ -5,7 +5,7 @@ Zabbix::Check - Zabbix Agent system and service checks
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -15,6 +15,8 @@ Zabbix Agent system and service checks
 
 =head2 Disk
 
+Zabbix check for disk
+
 =head3 zabbix_agentd.conf
 
 	UserParameter=cpan.zabbix.check.disk.discovery,/usr/bin/perl -MZabbix::Check::Disk -e_discovery
@@ -28,6 +30,8 @@ $2 I<Type: read|write|total>
 
 =head2 Supervisor
 
+Zabbix check for Supervisor service
+
 =head3 zabbix_agentd.conf
 
 	UserParameter=cpan.zabbix.check.supervisor.installed,/usr/bin/perl -MZabbix::Check::Supervisor -e_installed
@@ -41,6 +45,8 @@ $1 I<Worker name>
 
 =head2 RabbitMQ
 
+Zabbix check for RabbitMQ service
+
 =head3 zabbix_agentd.conf
 
 	UserParameter=cpan.zabbix.check.rabbitmq.installed,/usr/bin/perl -MZabbix::Check::RabbitMQ -e_installed
@@ -57,6 +63,21 @@ $2 I<Queue name>
 
 $3 I<Type: ready|unacked|total>
 
+=head2 Systemd
+
+Zabbix check for Systemd services
+
+=head3 zabbix_agentd.conf
+
+	UserParameter=cpan.zabbix.check.systemd.installed,/usr/bin/perl -MZabbix::Check::Systemd -e_installed
+	UserParameter=cpan.zabbix.check.systemd.check,/usr/bin/perl -MZabbix::Check::Systemd -e_check
+	UserParameter=cpan.zabbix.check.systemd.service_discovery,/usr/bin/perl -MZabbix::Check::Systemd -e_service_discovery
+	UserParameter=cpan.zabbix.check.systemd.service_status[*],/usr/bin/perl -MZabbix::Check::Systemd -e_service_status $1
+
+B<service_status $1>
+
+$1 I<Service name>
+
 =head1 INSTALLATION
 
 To install this module type the following
@@ -116,13 +137,13 @@ BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.01';
+	our $VERSION     = '1.02';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
-	our @EXPORT      = qw(zbxEncode zbxDecode);
+	our @EXPORT      = qw(zbxEncode zbxDecode printDiscovery whereisBin);
 	# Functions and variables which can be optionally exported
-	our @EXPORT_OK   = qw(printDiscovery whereisBin);
+	our @EXPORT_OK   = qw();
 }
 
 
@@ -181,9 +202,8 @@ sub printDiscovery
 				my %newitem = map({
 					my $key = $_;
 					my $val = $item->{$key};
-					my $newkey = zbxEncode($key);
-					$newkey = uc("{#$newkey}");
-					my $newval = zbxEncode($val);
+					my $newkey = uc("{#$key}");
+					my $newval = $val;
 					$newkey => $newval;
 				} keys(%$item));
 				\%newitem;
@@ -198,7 +218,7 @@ sub printDiscovery
 sub whereisBin
 {
 	my ($name) = @_;
-	return grep(-f $_, map("$_/$name", split(":", "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")));
+	return grep(-f $_, map("$_/$name", split(":", "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin")));
 }
 
 
