@@ -5,7 +5,7 @@ Zabbix::Check::RabbitMQ - Zabbix check for RabbitMQ service
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -34,14 +34,14 @@ no warnings qw(qw utf8);
 use v5.14;
 use utf8;
 
-use Zabbix::Check qw(printDiscovery whereisBin);
+use Zabbix::Check;
 
 
 BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.01';
+	our $VERSION     = '1.02';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
@@ -75,8 +75,8 @@ sub getVhosts
 
 sub getQueues
 {
-	my ($vhost) = @_;
 	return unless defined($rabbitmqctl) and -x $rabbitmqctl;
+	my ($vhost) = @_;
 	my $result = {};
 	my $first = 1;
 	for my $line (`$rabbitmqctl list_queues -p \"\Q$vhost\E\" name messages_ready messages_unacknowledged messages`)
@@ -102,9 +102,12 @@ sub _installed
 
 sub _check
 {
-	return unless defined($rabbitmqctl) and -x $rabbitmqctl;
-	system "$rabbitmqctl cluster_status >/dev/null 2>&1";
-	my $result = ($? == 0)? 1: 0;
+	my $result = 2;
+	if (defined($rabbitmqctl) and -x $rabbitmqctl)
+	{
+		system "$rabbitmqctl cluster_status >/dev/null 2>&1";
+		$result = ($? == 0)? 1: 0;
+	}
 	print $result;
 	return $result;
 }
@@ -113,7 +116,7 @@ sub _vhost_discovery
 {
 	my @items;
 	my $vhosts = getVhosts();
-	return unless $vhosts;
+	$vhosts = {} unless $vhosts;
 	for my $vhost (keys %$vhosts)
 	{ 
 		push @items, { vhost => $vhost };
@@ -125,11 +128,11 @@ sub _queue_discovery
 {
 	my @items;
 	my $vhosts = getVhosts();
-	return unless $vhosts;
+	$vhosts = {} unless $vhosts;
 	for my $vhost (keys %$vhosts)
 	{ 
 		my $queues = getQueues($vhost);
-		next unless $queues;
+		$queues = {} unless $queues;
 		for my $queue (keys %$queues)
 		{
 			push @items, { vhost => $vhost, queue => $queue };
@@ -140,11 +143,11 @@ sub _queue_discovery
 
 sub _queue_status
 {
-	my ($vhost, $queue, $type) = @ARGV;
+	my ($vhost, $queue, $type) = map(zbxDecode($_), @ARGV);
 	return unless $vhost and $queue and $type and $type =~ /^ready|unacked|total$/;
+	my $result = "";
 	my $queues = getQueues($vhost);
-	return unless defined $queues->{$queue};
-	my $result = $queues->{$queue}->{$type};
+	$result = $queues->{$queue}->{$type} if defined($queues->{$queue}->{$type});
 	print $result;
 	return $result;	
 }
